Interface: PointOptions | Chart.js
Description: Open source HTML5 Charts for your website

# # Interface: PointOptions

## # Hierarchy

- `CommonElementOptions`

  ↳ `PointOptions`

## # Properties

### # backgroundColor

• backgroundColor: `Color`

#### # Inherited from

CommonElementOptions.backgroundColor

#### # Defined in

index.esm.d.ts:1696
(opens new window)

### # borderColor

• borderColor: `Color`

#### # Inherited from

CommonElementOptions.borderColor

#### # Defined in

index.esm.d.ts:1695
(opens new window)

### # borderWidth

• borderWidth: `number`

#### # Inherited from

CommonElementOptions.borderWidth

#### # Defined in

index.esm.d.ts:1694
(opens new window)

### # drawActiveElementsOnTop

• drawActiveElementsOnTop: `boolean`

Draw the active elements over the other elements of the dataset,

`default` true

#### # Defined in

index.esm.d.ts:1904
(opens new window)

### # hitRadius

• hitRadius: `number`

Extra radius added to point radius for hit detection.

`default` 1

#### # Defined in

index.esm.d.ts:1889
(opens new window)

### # pointStyle

• pointStyle: `PointStyle`

Point style

`default` 'circle;

#### # Defined in

index.esm.d.ts:1894
(opens new window)

### # radius

• radius: `number`

Point radius

`default` 3

#### # Defined in

index.esm.d.ts:1884
(opens new window)

### # rotation

• rotation: `number`

Point rotation (in degrees).

`default` 0

#### # Defined in

index.esm.d.ts:1899
(opens new window)